@@ -9,7 +9,7 @@ use JavaScript::SpiderMonkey;
 use JSON;
 
 our $JSLIB;
-our $VERSION = '0.090_04';
+our $VERSION = '0.100';
 
 sub new
 {
@@ -79,12 +79,7 @@ Please report any bugs to L<http://rt.cpan.org/>.
 
 =head1 SEE ALSO
 
-Specification: L<http://goessner.net/articles/jsont/>.
-
-Related modules: L<JSON>, L<JSON::Path>, L<JSON::GRDDL>,
-L<JSON::Hyper>, L<JSON::Schema>.
-
-Requires: L<JSON>, L<JavaScript::SpiderMonkey>.
+L<JSON::T>.
 
 =head1 AUTHOR
 
